@@ -13,7 +13,7 @@
 ##############################################################################
 """Zope publication
 
-$Id: zopepublication.py 100089 2009-05-18 18:46:06Z icemac $
+$Id: zopepublication.py 100293 2009-05-23 20:23:34Z shane $
 """
 __docformat__ = 'restructuredtext'
 
@@ -35,17 +35,16 @@ from zope.security.management import newInteraction, endInteraction
 from zope.security.checker import ProxyFactory
 from zope.security.proxy import removeSecurityProxy
 from zope.traversing.interfaces import IPhysicallyLocatable
+from zope.traversing.interfaces import IEtcNamespace
 from zope.location import LocationProxy
 from zope.error.interfaces import IErrorReportingUtility
 
 import zope.authentication.interfaces
-from zope.app.applicationcontrol.applicationcontrol \
-     import applicationControllerRoot
 from zope.browser.interfaces import ISystemErrorView
 from zope.app.publication.interfaces import BeforeTraverseEvent
 from zope.app.publication.interfaces import EndRequestEvent
-from zope.app.publication.publicationtraverse import PublicationTraverse
-from zope.app.publisher.browser import queryDefaultViewName
+from zope.traversing.publicationtraverse import PublicationTraverse
+from zope.publisher.defaultview import queryDefaultViewName
 from zope.authentication.interfaces import IUnauthenticatedPrincipal
 from zope.authentication.interfaces import IFallbackUnauthenticatedPrincipal
 from zope.authentication.interfaces import IAuthentication
@@ -137,12 +136,14 @@ class ZopePublication(PublicationTraverse):
         pass
 
     def getApplication(self, request):
-        # If the first name is '++etc++process', then we should
-        # get it rather than look in the database!
+        # If '++etc++process' is in the path, then we should
+        # get the parent of the application controller rather than
+        # open the database.
         stack = request.getTraversalStack()
 
         if '++etc++process' in stack:
-            return applicationControllerRoot
+            obj = zope.component.getUtility(IEtcNamespace, 'process')
+            return obj.__parent__
 
         # Open the database.
         conn = self.db.open()
